##@namespace stomp.constants
# The STOMP command and header name strings.

HDR_ACCEPT_VERSION = 'accept-version'
HDR_ACK = 'ack'
HDR_CONTENT_LENGTH = 'content-length'
HDR_CONTENT_TYPE = 'content-type'
HDR_DESTINATION = 'destination'
HDR_HEARTBEAT = 'heart-beat'
HDR_HOST = 'host'
HDR_ID = 'id'
HDR_MESSAGE_ID = 'message-id'
HDR_LOGIN = 'login'
HDR_PASSCODE = 'passcode'
HDR_RECEIPT = 'receipt'
HDR_SUBSCRIPTION = 'subscription'
HDR_TRANSACTION = 'transaction'

CMD_ABORT = 'ABORT'
CMD_ACK = 'ACK'
CMD_BEGIN = 'BEGIN'
CMD_COMMIT = 'COMMIT'
CMD_CONNECT = 'CONNECT'
CMD_DISCONNECT = 'DISCONNECT'
CMD_NACK = 'NACK'
CMD_STOMP = 'STOMP'
CMD_SEND = 'SEND'
CMD_SUBSCRIBE = 'SUBSCRIBE'
CMD_UNSUBSCRIBE = 'UNSUBSCRIBE'